@@ -38,7 +38,7 @@ $authen
 </form>
 );
 } else {
-    my $lg = "javascript:menu();requestURI('$ENV{SCRIPT_NAME}?action=logout','logout','logout')";
+    my $lg = "javascript:closeMenu();requestURI('$ENV{SCRIPT_NAME}?action=logout','logout','logout')";
     my $welcome = translate('welcome');
     my $logout  = translate('logout');
     $m_sContent .= qq ($welcome, $m_sUser <br/><a  class="link" href="$lg">$logout</a><br/>);
