@@ -1,37 +1,37 @@
 $VAR1 = {
-          'database' => {
-                          'CurrentUser' => 'root',
-                          'CurrentHost' => 'localhost',
-                          'host' => 'localhost',
-                          'user' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'password' => 'keinz',
-                          'name' => 'LZE',
-                          'CurrentPass' => 'keinz'
-                        },
-          'language' => 'en',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'floodtime' => 10,
+          'version' => '0.74',
           'config' => '/var/www/cgi-bin/config/settings.pl',
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'floodtime' => 10,
-          'scriptAlias' => 'cgi-bin',
-          'cgi' => {
-                     'style' => 'mysql',
-                     'bin' => '/var/www/cgi-bin',
-                     'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'cookiePath' => '/',
-                     'alias' => 'cgi-bin',
-                     'title' => 'MySQL::Admin',
-                     'serverName' => 'http://localhost'
-                   },
           'admin' => {
                        'email' => 'dirk.lze@gmail.com',
-                       'name' => 'Lindner',
                        'firstname' => 'Dirk',
-                       'password' => 'testpass'
+                       'password' => 'testpass',
+                       'name' => 'Lindner'
                      },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'version' => '0.73',
-          'translate' => '/var/www/cgi-bin/config/translate.pl'
+          'scriptAlias' => 'cgi-bin',
+          'cgi' => {
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'bin' => '/var/www/cgi-bin',
+                     'serverName' => 'http://localhost',
+                     'expires' => '+1y',
+                     'cookiePath' => '/',
+                     'style' => 'mysql',
+                     'alias' => 'cgi-bin',
+                     'title' => 'MySQL::Admin'
+                   },
+          'language' => 'en',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'database' => {
+                          'CurrentHost' => 'localhost',
+                          'user' => 'root',
+                          'CurrentUser' => 'root',
+                          'password' => 'keinz',
+                          'name' => 'LZE',
+                          'CurrentPass' => 'keinz',
+                          'host' => 'localhost',
+                          'CurrentDb' => 'LZE'
+                        }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
