@@ -38,7 +38,7 @@ $VAR1 = {
                     'showdatabases' => 'Databases',
                     'sql' => 'SQL',
                     'optimizetable' => 'Optimize Table',
-                    'changecurrentdb' => 'Change Database connection',
+                    'changecurrentdb' => 'Server',
                     'insertafter' => 'After',
                     'indexover' => 'Index over',
                     'wrong_username_text' => 'The Username must be at least 3 characters in length and can only contain letters or digits.',
@@ -60,8 +60,8 @@ $VAR1 = {
                     'showcreatetable' => 'New Table',
                     'login' => 'Login',
                     'repairtable' => 'Repair Table',
-                    'showusers' => 'Show Users',
-                    'execsql' => 'Exec Sql',
+                    'showusers' => 'User',
+                    'execsql' => 'Sql',
                     'regexp' => 'Regular Expression',
                     'select_all' => 'Select All',
                     'drop_database' => 'Drop Database',
@@ -71,7 +71,7 @@ $VAR1 = {
                     'showcreatedatabase' => 'New Database',
                     'user' => 'Username',
                     'unselect_all' => 'Unselect',
-                    'showsqleditor' => 'Execute Sql',
+                    'showsqleditor' => 'Sql',
                     'search' => 'Search',
                     'shownewentry' => 'New Entry',
                     'welcome' => 'Welcome',
@@ -81,7 +81,7 @@ $VAR1 = {
                     'starttable' => 'at start',
                     'rights' => 'rights',
                     'field' => 'field',
-                    'showchangecurrentdb' => 'Change ',
+                    'showchangecurrentdb' => 'Server',
                     'host' => 'host',
                     'showprocesslist' => 'Processlist',
                     'showtable' => 'showtable',
@@ -89,7 +89,7 @@ $VAR1 = {
                     'showdumpdatabase' => 'Export',
                     'showdumptable' => 'Export',
                     'sqlsearch' => 'Search',                
-                    'sqleditor' => 'Execute Sql',
+                    'sqleditor' => 'Sql',
                     'new' => 'New',
                     'ShowTableDetails' => 'Details',
 		    'DropTable'=> 'Tables',
@@ -104,8 +104,21 @@ $VAR1 = {
                     'shownewrow'    => 'New Row',
 		    'showProfile'=> 'Profile',
 		    'saveProfile'=> 'Profile',
-		    'retry'=> 'Retry',
-		    'newpass'=> 'New Password',
+		    'retry'    => 'retry',
+		    'newpass'  => 'New Password',
+		    'EditIndex'=> 'Index bearbeiten',    
+		    'AddIndex' => 'Index hinzufügen',
+		    'AddUnique'=> 'Unique Index hinzufügen',
+		    'DropColumn'=> 'Drop Column',
+		    'Default'=> 'Default',
+		    'Extra' => 'Extra',
+		    'Attribute'=> 'Attribute',
+		    'AddPrimaryKey'=> 'AddPrimaryKey',    
+		    'Null'=> 'Null',
+		    'LENGTH' => 'LENGTH',
+		    'ShowNewTable'=> 'New Table',    
+		    'searchDatabase' => 'Search',
+		    'AddFulltext' => 'Add Fulltext',
                   },
           'de' => {
                     'host' => 'host',
@@ -116,7 +129,7 @@ $VAR1 = {
                     'showcreateuser' => 'Benutzer',
                     'welcome' => 'Willkommen',
                     'field' => 'Feld',
-                    'showchangecurrentdb' => 'Datenbank wechseln',
+                    'showchangecurrentdb' => 'Server',
                     'register' => 'Registrieren',
                     'starttable' => 'am Anfang',
                     'rights' => 'Rechte',
@@ -155,7 +168,7 @@ $VAR1 = {
                     'optimizetable' => 'Optimieren',
                     'indexover' => 'Index über',
                     'wrong_username_text' => 'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
-                    'changecurrentdb' => 'Benutzer wechseln',
+                    'changecurrentdb' => 'Server',
                     'insertafter' => 'Einfügen',
                     'createuser' => 'Neuer Benutzer',
                     'save' => 'Speichern',
@@ -210,10 +223,23 @@ $VAR1 = {
 		    'codenotcheckedfileerror'=> '',
 		    'failednotindatabase'=> '',
 		    'failedinvalidcode'=> 'Falscher Code',
-		    'showProfile'=> 'Profile',
-		    'saveProfile'=> 'Profile',
-		    'retry'=> 'Wiederhohlen',
-		    'newpass'=> 'Neues Passwort',
+		    'showProfile' => 'Profile',
+		    'saveProfile' => 'Profile',
+		    'retry'       => 'Wiederhohlen',
+		    'newpass'     => 'Neues Passwort',
+		    'EditIndex'   => 'Index bearbeiten',    
+		    'AddIndex'    => 'Index hinzufügen',
+		    'AddUnique'   => 'Unique Index hinzufügen',
+		    'AddFulltext' => 'Add Fulltext',
+		    'DropColumn'  => 'Spalte löschen',
+		    'Default'     => 'Default',
+		    'Extra'       => 'Extra',
+		    'Attribute'=> 'Attribute',
+		    'AddPrimaryKey'=> 'Primärschlüssel hinzufügen',    
+		    'Null'=> 'Null',
+		    'LENGTH' => 'LENGTH',
+		    'ShowNewTable'=> 'Neue Tabelle',    
+		    'searchDatabase' => 'Suchen',
                   }
         };
 $lang =$VAR1;
\ No newline at end of file
