@@ -4,14 +4,14 @@ function init(){
 	loadHistory();
 	translate();
 }
-function alert(txt){
-	visible('popup');
-        setText('popupContent','<div align="center">'+txt+'<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
-	var node = $("confirmButton");
-	node.addEventListener('click', function (evt){
-	  hide('popup');
-	});
-}
+// function alert(txt){
+// 	visible('popup');
+//         setText('popupContent','<div align="center">'+txt+'<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
+// 	var node = $("confirmButton");
+// 	node.addEventListener('click', function (evt){
+// 	  hide('popup');
+// 	});
+// }
 function confirm2(txt,sub,arg,arg2,arg3){
 	visible('popup');
 	var sleep = true;
@@ -315,8 +315,8 @@ function setContent() {
 		if (navigator.userAgent.indexOf("Firefox")!=-1)
 		    txt = txt.replace("<![CDATA[", "").replace("]]>", "");
 		setText(outID,txt);
+		evalId(outID);
 	      }
-	      evalId(outID);
 	   }else{
 		setText('content',oldpage);
 		setCurrentTab(currentId, currentTxt);
@@ -350,6 +350,10 @@ window.onerror = logError;
 function logError(a,b,c){
        alert(a+" "+" "+b+" "+c);
 }
+window.onerror = logError;
+function logError(a,b,c){
+       alert(a+" "+" "+b+" "+c);
+}
 window.onpopstate =loadHistory;
 function loadHistory(){
 	var rxObj =  new RegExp(/action=([^&]+)/);
@@ -358,6 +362,7 @@ function loadHistory(){
 	var rxObj2 =  new RegExp(/(\?[^\?]+$)/);
 	rxObj2.exec(window.location.search);
 	var uri = RegExp.$1;
+	var url = window.location.search;
 	if(uri && action)
 	  requestURI('cgi-bin/mysql.pl'+uri,action,action,false);
 	else
@@ -417,8 +422,8 @@ function Autocomplete(evt){
 		  break;
 		}
 		i++;
-	    }
-      offset++;
+	}
+	offset++;
       }
 }
 function selKeyword(id){
@@ -461,25 +466,35 @@ function insertAtCursorPosition(txt){
              textarea.value += txt;	
        }
 }
-
-function toolbar(){
-    displayTree('toolbar2');  
-    displayTree('toolbar'); 
+var timer;
+function toolbarOver(){
+    timer = setTimeout(function lol(){showToolbar('toolbar');showToolbar('toolbar2');},300)
 }
-
-function displayTree(id){
+function toolbarOut(){
+   clearTimeout(timer);
+}
+function closeToolbar(){
+    hideToolbar('toolbar2');
+    hideToolbar('toolbar');
+}
+function showToolbar(id){
+  var entry = $(id);
+  if(entry && entry.firstChild){
+  entry.classList.remove('closed');
+  if(entry.firstChild)
+	  entry.firstChild.style.display ='';
+  }
+  var node = $('toolbarTable');
+  node.addEventListener ('mouseleave', function (evt) {
+  closeToolbar();
+  });
+}
+function hideToolbar(id){
   var entry = $(id);
   if(entry && entry.firstChild){
-    if(entry.firstChild.style.display == 'none'){
-      bToolbar = true;
-      entry.classList.remove('closed');
-        if(entry.firstChild)
-		entry.firstChild.style.display ='';
-    }else{
       entry.classList.add('closed');
-      bToolbar = false;
         if(entry.firstChild)
 		entry.firstChild.style.display ='none';
-    }
   }
-}
\ No newline at end of file
+  clearTimeout(timer);
+}
