@@ -51,10 +51,11 @@ use vars qw(
   $m_sCurrentPass
   $m_sAjax
   $m_nSkipCaptch
+  $m_hrLng
 );
 @MySQL::Admin::GUI::EXPORT  = qw(ContentHeader Body ChangeDb Unique);
 @ISA                        = qw(Exporter MySQL::Admin);
-$MySQL::Admin::GUI::VERSION = '0.73';
+$MySQL::Admin::GUI::VERSION = '0.74';
 $m_bMod_perl                = ( $ENV{MOD_PERL} ) ? 1 : 0;
 local $^W = 0;
 $m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
@@ -85,6 +86,8 @@ MySQL::Admin::GUI - Just a MySQL administration Web-App
 sub ContentHeader {
     my $m_hrSettingsfile = shift;
     init($m_hrSettingsfile);
+    #todo klären wiso m_hrLng durch init() nicht gesetzt wird.
+#     *m_hrLng = \$MySQL::Admin::Translate::lang;
     $m_oDatabase = new DBI::Library::Database();
     $m_oDatabase->rewrite( $m_hrSettings->{cgi}{mod_rewrite} );
     $m_oDatabase->serverName( $m_hrSettings->{cgi}{serverName} );
